diffstatus

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package diffstatus displays a persistent status line for difference search. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clear

func Clear()

Clear the diff status display. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func ClearMessage

func ClearMessage()

ClearMessage clears the custom status message, reverting to statusFn callback. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func Draw

func Draw()

Draw the diff search status line. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func Init

func Init()

Init initializes the diff status window at the specified position. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func IsActive

func IsActive() bool

IsActive returns true if diff search is active and status should be shown. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func Resize

func Resize(x, y, width, height int)

Resize the diff status window. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func SetActiveFn

func SetActiveFn(fn func() bool)

SetActiveFn sets the callback to check if diff search is active. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func SetMessage

func SetMessage(text string)

SetMessage sets a custom status message that takes priority over the statusFn callback. Use this for persistent status updates like "Different: X - Y" that should not auto-dismiss. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

func SetStatusFn

func SetStatusFn(fn func() string)

SetStatusFn sets the callback to get the status text. [IMPL:DIFF_SEARCH] [ARCH:DIFF_SEARCH] [REQ:DIFF_SEARCH]

Types

This section is empty.

Jump to